# Plugin for TWiki Collaboration Platform, http://TWiki.org/
#
# @(#)$Id: $ (c) Peter Klausner
# GNU Copyright (C) 2003 Peter Klausner plausner@bluewinc.h
#
# See http://twiki.org/cgi-bin/view/Plugins/GeoURLPlugin

# =========================
package TWiki::Plugins::GeoURLPlugin;    # change the package name and $pluginName!!!

# =========================
use vars qw(
        $web $topic $user $installWeb $VERSION $pluginName
        $debug $exampleCfgVar
    );

$VERSION = '1.010';
$pluginName = 'GeoURLPlugin';  # Name of this Plugin

# =========================
sub initPlugin
{
    ( $topic, $web, $user, $installWeb ) = @_;

    # check for Plugins.pm versions
    if( $TWiki::Plugins::VERSION < 1 ) {
        TWiki::Func::writeWarning( "Version mismatch between $pluginName and Plugins.pm" );
        return 0;
    }

    # data...
    $position =	"";
    $lat =	"";
    $lon =	"";
    $title =	"";

    $dist = &TWiki::Prefs::getPreferencesValue( "GEOURLPLUGIN_DIST" )
	or
    $dist = 30;

    return 0;
}

# =========================
sub commonTagsHandler    # Called line by line for body text PLUS all the page template...
{
    if ( "$lat" )	{ # latitude (+ longitude) have been parsed from GEOURL
	$_[0] =~ s(%GEOMETA%)
	    (<meta name="ICBM" content="$position"><meta name="DC.title" content="$title">)o;
    }
    else	{
	$_[0] =~ s(%GEOMETA%)();
    }
}

# =========================
sub endRenderingHandler
{
    $_[0] =~ s/%GEOURL{(.*?)}%/saveGeoUrl($1)/geo;	# not global
    $_[0] =~ s/%GEOURL%/&renderGeoUrl/eo;	# no need for global
}

# =========================
sub saveGeoUrl
{
	$position = &TWiki::extractNameValuePair( $_[0] );
	$title = &TWiki::extractNameValuePair( $_[0], "title" );
	my $alt = &TWiki::extractNameValuePair( $_[0], "alt" );
	my $radius = &TWiki::extractNameValuePair( $_[0], "dist" );
	
	$dist = $radius	if $radius;
    	$title = "$topic ($web)"	unless $title;

	$position =~ /^(\s*[+-]*[0-9.]+)\s+([+-]*[0-9.]+)\s*$/;
	$lat = $1;
	$lon = $2;
	$alt ? return $alt : return renderGeoUrl();
}

# =========================
sub renderGeoUrl
{
	return "<a href=\"http://geourl.org/near/?lat=$lat&lon=$lon&dist=$dist\""
	.	" title=\"Within $dist miles of $title\">"
	.	'<span style="font-family: verdana,geneva,arial,helvetica,sans-serif;'
	.	'font-size:x-small;font-weight:normal;text-decoration:none;color: white;'
	.	'background-color: #093;border-left:1px solid #3C6;'
	.	'border-top:1px solid #3C6;border-right:1px solid #063;'
	.	'border-bottom:1px solid #063;padding:0px 3px 0px 3px;'
	.	'margin:0px;">GeoURL</span></a>';
}

# =========================

1;
